@@ -8,13 +8,11 @@ url_metadata = [
         'app': 'openwisp_users',
         'include': {'module': 'openwisp_users.accounts.urls'},
     },
-    # django-netjsonconfig schemas
+    # openwisp_notifications
     {
-        'regexp': r'^',
-        'include': {
-            'module': 'django_netjsonconfig.urls',
-            'namespace': 'netjsonconfig',
-        },
+        'regexp': '',
+        'app': 'openwisp_notifications',
+        'include': {'module': 'openwisp_notifications.urls'},
     },
     # openwisp_controller.pki (CRL view)
     {
@@ -40,6 +38,12 @@ url_metadata = [
         'app': 'openwisp_controller.geo',
         'include': {'module': '{app}.api.urls', 'namespace': 'geo'},
     },
+    # openwisp_controller.config
+    {
+        'regexp': r'^',
+        'app': 'openwisp_controller.config',
+        'include': {'module': '{app}.urls', 'namespace': 'config'},
+    },
 ]
 
 urlpatterns = []
